function rank_list = gcd(normalized_conductance, alpha, K)
% normalized_conductance:- A square matrix having conductance information
% alpha used for personalized page rank
% K is the number of ranks till which rank list is required

    rank_list = zeros(K,1); %will contain the id of itmes at each rank
    p = zeros(1,size(normalized_conductance,2)); % will contain weighted personalized page rank till current rank
    weight = ones(K,1); % will contain the weight used for summing each rank
    weight = weight ./ K; % I am using equal weight for each rank (try with others as well)
    
    PPV = getPPV(alpha, normalized_conductance); % returns personalized page-rank vector
    totalweight =0;
    
    for i=1:K   % for each rank position
        max_id = -1;
        max_value = -inf;
        for j =1:size(normalized_conductance,1)     %for each elements to be ranked
            if(sum(ismember(rank_list,j)) > 0 )     % if the element is already in the list 
               continue;                            % continue
            end
            ent = entropy(addNormalizedArray(p,PPV(j,:),totalweight,weight(i,1)));  % Find resulting entropy if this element is added
                                                                                    % Note that entropy is not the only meassure
                                                                                    %refer paper, It can be L1, L2 or KL instead of entropy
            if ent > max_value      %check how the entropy increases when this element is added
               max_id = j; 
               max_value = ent;
            end            
        end     %end for each item
        rank_list(i,1) = max_id;    % max_id now contains the id of the element adding has maximum effect on the entropy
        p = addNormalizedArray(p,PPV(max_id,:),totalweight,weight(i,1));    %add the item's PPV to p
        totalweight = totalweight + weight(i,1);    %increment weight
    end  %end for each rank position